get_exchange_rates: Returns the exchange rates from one currency to another from...

Description Usage Arguments Value Examples

View source: R/get_conversion_rate.R

Description

Returns the exchange rates from one currency to another from a start to an end-date

Usage

1
2
3
4
5
6
7
get_exchange_rates(
  fromCUR,
  toCUR,
  start_date = Sys.Date() - 30,
  end_date = Sys.Date(),
  retried = 0
)

Arguments

fromCUR

base currency that you want to convert

toCUR

final currency

start_date

date

end_date

date

retried

count the number of tries

Value

data.table object

Examples

1
2
get_exchange_rates('EUR', 'USD', start_date = '2020-05-12', end_date = '2020-05-13')
get_exchange_rates('EUR', 'HUF', start_date = '2020-05-12', end_date = '2020-05-13')

yurialmeida5/ya_pkg documentation built on Dec. 23, 2021, 8:21 p.m.